## usethis namespace: start
#' @useDynLib clubpro, .registration = TRUE
## usethis namespace: end
NULL

## usethis namespace: start
#' @importFrom Rcpp sourceCpp
## usethis namespace: end
NULL

## usethis namespace: start
#' @importFrom grDevices palette
## usethis namespace: end
NULL

## usethis namespace: start
#' @importFrom stats na.omit
## usethis namespace: end
NULL

## usethis namespace: start
#' @importFrom stats median
## usethis namespace: end
NULL

## usethis namespace: start
#' @importFrom lattice dotplot
## usethis namespace: end
NULL

## usethis namespace: start
#' @importFrom lattice histogram
## usethis namespace: end
NULL

## usethis namespace: start
#' @importFrom lattice panel.superpose
## usethis namespace: end
NULL

## usethis namespace: start
#' @importFrom lattice panel.histogram
## usethis namespace: end
NULL

## usethis namespace: start
#' @importFrom lattice panel.abline
## usethis namespace: end
NULL


## usethis namespace: start
#' @importFrom graphics mosaicplot
## usethis namespace: end
NULL
